#!/bin/bash

set -x
set -eu
set -o pipefail

gluon_fork_git_url="ssh://git@gitlab.freifunk-stuttgart.de:22220/nrb/gluon-test.git"
gluon_upstream_git_url="https://github.com/freifunk-gluon/gluon.git"
site_git_url="ssh://git@gitlab.freifunk-stuttgart.de:22220/firmware/site-ffs.git"

upstream_newest_minor=$(git ls-remote --tags --refs https://github.com/freifunk-gluon/gluon.git 'refs/tags/v2018.2*' | cut -d/ -f3 | sort -r -n -t. -k2 | head -n1)
# branch name in our forked gluon
fork_newest_minor_branch="$upstream_newest_minor-ffs"
fork_newest_minor_tag="$upstream_newest_minor-ffs0.1"

git clone "$gluon_fork_git_url" gluon
cd gluon
git remote add upstream "$gluon_upstream_git_url"
git fetch upstream --tags

# we already have this branch - exit
if git rev-parse --verify "$fork_newest_minor_branch" &> /dev/null; then
    echo "Nothing todo, branch $fork_newest_minor_branch already exists"
    exit 1
fi

git checkout "$upstream_newest_minor"
git am ../patches/0001-resize-x86-rootfs-to-36-MB-and-kernel-to-16-MB.patch
git checkout -b "$fork_newest_minor_branch"
git tag "$fork_newest_minor_tag"
git push origin "$fork_newest_minor_branch"
git push origin "$fork_newest_minor_tag"

new_gluon_rev=$(git rev-parse HEAD)

cd ..

git clone --recurse "$site_git_url"

cd site-ffs
git checkout nightly

git -C gluon fetch
git -C gluon checkout $new_gluon_rev
git -C gluon submodule update

git add gluon
git commit -m "automatic update to gluon $fork_newest_minor_tag"
git push
